@@ -25,36 +25,40 @@ known_sources = [
 
     # level 2
 
+    'rocq-stdlib',
+
+    # level 3
+
     'aac-tactics', 'coq-bignums', 'coq-dpdgraph', 'coq-elpi',
     'coq-ext-lib', 'coq-hammer', 'coq-hott', 'coq-libhyps',
     'coq-menhirlib', 'coq-record-update', 'coq-reduction-effects',
     'coq-stdpp', 'coq-unicoq', 'coq-unimath', 'flocq', 'ott',
-    'paramcoq', 'coq-serapi',
+    'paramcoq',
 
-    # level 3
+    # level 4
 
     'coq-equations', 'coq-gappa', 'coq-hierarchy-builder', 'coq-iris',
     'coq-math-classes', 'coq-mtac2', 'coq-simple-io', 'coqprime',
 
-    # level 4
-
-    'ssreflect', 'coq-corn', 'metacoq',
-
     # level 5
 
+    'ssreflect', 'coq-corn',
+
+    # level 6
+
     'coq-deriving', 'coq-reglang', 'coq-relation-algebra',
     'coquelicot', 'mathcomp-bigenough', 'mathcomp-finmap',
     'mathcomp-zify', 'coq-quickchick',
 
-    # level 6
+    # level 7
 
     'coq-extructures', 'coq-interval',
     'mathcomp-algebra-tactics', 'mathcomp-analysis',
     'mathcomp-multinomials', 'mathcomp-real-closed',
 
-    # level 7
+    # level 8
 
-    'coqeal' #, 'mathcomp-abel'
+    'coqeal'
 
 ]
 
@@ -97,7 +101,6 @@ known_tests = {
     'coq-unimath': ('-type-in-type', 'UniMath', 'All'),
     'elpi': (None, 'Coq', 'Reals'),
     'flocq': (None, 'Flocq', 'Version'),
-    # 'mathcomp-abel': (None, 'Abel', 'abel'),
     'mathcomp-algebra-tactics': (None, 'mathcomp.algebra_tactics', 'ring'),
     'mathcomp-analysis': (None, 'mathcomp.analysis', 'topology'),
     'mathcomp-bigenough': (None, 'mathcomp', 'bigenough'),
@@ -108,6 +111,7 @@ known_tests = {
     'metacoq': (None, 'MetaCoq.Template', 'All'),
     'ott': (None, 'Ott', 'ott_list'),
     'paramcoq': (None, 'Param', 'Param'),
+    'rocq-stdlib': (None, 'Stdlib', 'QArith'),
     'ssreflect': (None, 'mathcomp', 'ssreflect'),
 }
 
@@ -127,10 +131,10 @@ def check_known_tests():
 def guess_binary_name(srcname):
     if srcname == 'coq':
         return 'libcoq-stdlib'
-    if srcname == 'coq-serapi':
-        return 'libcoq-serapi-ocaml'
     if srcname == 'elpi':
         return 'libelpi-ocaml'
+    if srcname == 'rocq-stdlib':
+        return 'libcoq-stdlib'
     if srcname == 'ssreflect':
         return 'libcoq-mathcomp-ssreflect'
     if srcname.startswith('coq-'):
